@@ -3,26 +3,26 @@
 use std::path::PathBuf;
 
 use crate::{
-    commands::open_repository,
+    commands::{get_repository, init::init, open_repository},
     helpers::bytes_size_to_string,
-    {status_err, Application, RUSTIC_APP},
+    status_err, Application, RUSTIC_APP,
 };
+
 use abscissa_core::{Command, Runnable, Shutdown};
 use anyhow::{bail, Context, Result};
 use log::{debug, info, warn};
-
 use merge::Merge;
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
+use serde_with::{serde_as, OneOrMany};
 
 use rustic_core::{
     BackupOptions, ConfigOptions, KeyOptions, LocalSourceFilterOptions, LocalSourceSaveOptions,
-    ParentOptions, PathList, Repository, SnapshotOptions,
+    ParentOptions, PathList, SnapshotOptions,
 };
 
-use super::init::init;
-
 /// `backup` subcommand
-#[derive(Clone, Command, Default, Debug, clap::Parser, Deserialize, Merge)]
+#[serde_as]
+#[derive(Clone, Command, Default, Debug, clap::Parser, Serialize, Deserialize, Merge)]
 #[serde(default, rename_all = "kebab-case", deny_unknown_fields)]
 // Note: using cli_sources, sources and source within this struct is a hack to support serde(deny_unknown_fields)
 // for deserializing the backup options from TOML
@@ -52,11 +52,21 @@ pub struct BackupCmd {
     #[serde(flatten)]
     ignore_save_opts: LocalSourceSaveOptions,
 
+    /// Don't scan the backup source for its size - this disables ETA estimation for backup.
+    #[clap(long)]
+    #[merge(strategy = merge::bool::overwrite_false)]
+    pub no_scan: bool,
+
     /// Output generated snapshot in json format
     #[clap(long)]
     #[merge(strategy = merge::bool::overwrite_false)]
     json: bool,
 
+    /// Don't show any output
+    #[clap(long, conflicts_with = "json")]
+    #[merge(strategy = merge::bool::overwrite_false)]
+    quiet: bool,
+
     /// Initialize repository, if it doesn't exist yet
     #[clap(long)]
     #[merge(strategy = merge::bool::overwrite_false)]
@@ -97,7 +107,8 @@ pub struct BackupCmd {
     /// Backup source, used within config file
     #[clap(skip)]
     #[merge(skip)]
-    source: String,
+    #[serde_as(as = "OneOrMany<_>")]
+    source: Vec<String>,
 }
 
 /// Merge backup sources
@@ -125,9 +136,7 @@ impl Runnable for BackupCmd {
 impl BackupCmd {
     fn inner_run(&self) -> Result<()> {
         let config = RUSTIC_APP.config();
-
-        let po = config.global.progress_options;
-        let repo = Repository::new_with_progress(&config.repository, po)?;
+        let repo = get_repository(&config.repository)?;
         // Initialize repository if --init is set and it is not yet initialized
         let repo = if self.init && repo.config_id()?.is_none() {
             if config.global.dry_run {
@@ -138,7 +147,7 @@ impl BackupCmd {
             }
             init(repo, &self.key_opts, &self.config_opts)?
         } else {
-            open_repository(&config)?
+            open_repository(&config.repository)?
         }
         .to_indexed_ids()?;
 
@@ -157,10 +166,13 @@ impl BackupCmd {
         let config_sources: Vec<_> = config_opts
             .iter()
             .map(|opt| -> Result<_> {
-                Ok(PathList::from_string(&opt.source)?
+                Ok(PathList::from_iter(&opt.source)
                     .sanitize()
                     .with_context(|| {
-                        format!("error sanitizing source=\"{}\" in config file", opt.source)
+                        format!(
+                            "error sanitizing source=\"{:?}\" in config file",
+                            opt.source
+                        )
                     })?
                     .merge())
             })
@@ -175,7 +187,7 @@ impl BackupCmd {
 
         let sources = match (self.cli_sources.is_empty(), config_opts.is_empty()) {
             (false, _) => {
-                let item = PathList::from_strings(&self.cli_sources).sanitize()?;
+                let item = PathList::from_iter(&self.cli_sources).sanitize()?;
                 vec![item]
             }
             (true, false) => {
@@ -202,7 +214,7 @@ impl BackupCmd {
                 }
                 // merge Options from config file using as_path, if given
                 if let Some(path) = path.as_os_str().to_str() {
-                    if let Some(idx) = config_opts.iter().position(|opt| opt.source == path) {
+                    if let Some(idx) = config_opts.iter().position(|opt| opt.source == vec![path]) {
                         info!("merging source=\"{path}\" section from config file");
                         opts.merge(config_opts[idx].clone());
                     }
@@ -218,13 +230,14 @@ impl BackupCmd {
                 .parent_opts(opts.parent_opts)
                 .ignore_save_opts(opts.ignore_save_opts)
                 .ignore_filter_opts(opts.ignore_filter_opts)
+                .no_scan(opts.no_scan)
                 .dry_run(config.global.dry_run);
-            let snap = repo.backup(&backup_opts, source.clone(), opts.snap_opts.to_snapshot()?)?;
+            let snap = repo.backup(&backup_opts, &source, opts.snap_opts.to_snapshot()?)?;
 
             if opts.json {
                 let mut stdout = std::io::stdout();
                 serde_json::to_writer_pretty(&mut stdout, &snap)?;
-            } else {
+            } else if !opts.quiet {
                 let summary = snap.summary.unwrap();
                 println!(
                     "Files:       {} new, {} changed, {} unchanged",
