@@ -8,19 +8,18 @@ pub(crate) mod progress_options;
 
 use std::{collections::HashMap, path::PathBuf};
 
-use directories::ProjectDirs;
-
-use merge::Merge;
-
 use abscissa_core::config::Config;
 use abscissa_core::path::AbsPathBuf;
 use abscissa_core::FrameworkError;
 use clap::Parser;
+use directories::ProjectDirs;
 use itertools::Itertools;
 use log::Level;
+use merge::Merge;
 use rustic_backend::BackendOptions;
 use rustic_core::RepositoryOptions;
 use serde::{Deserialize, Serialize};
+use serde_with::{serde_as, OneOrMany};
 
 #[cfg(feature = "webdav")]
 use crate::commands::webdav::WebDavCmd;
@@ -36,7 +35,7 @@ use crate::{
 ///
 /// # Example
 // TODO: add example
-#[derive(Clone, Default, Debug, Parser, Deserialize, Merge)]
+#[derive(Clone, Default, Debug, Parser, Deserialize, Serialize, Merge)]
 #[serde(default, rename_all = "kebab-case", deny_unknown_fields)]
 pub struct RusticConfig {
     /// Global options
@@ -69,7 +68,7 @@ pub struct RusticConfig {
     pub webdav: WebDavCmd,
 }
 
-#[derive(Clone, Default, Debug, Parser, Deserialize, Merge)]
+#[derive(Clone, Default, Debug, Parser, Serialize, Deserialize, Merge)]
 #[serde(default, rename_all = "kebab-case")]
 pub struct AllRepositoryOptions {
     /// Backend options
@@ -126,6 +125,7 @@ impl RusticConfig {
 /// Global options
 ///
 /// These options are available for all commands.
+#[serde_as]
 #[derive(Default, Debug, Parser, Clone, Deserialize, Serialize, Merge)]
 #[serde(default, rename_all = "kebab-case", deny_unknown_fields)]
 pub struct GlobalOptions {
@@ -139,6 +139,7 @@ pub struct GlobalOptions {
         env = "RUSTIC_USE_PROFILE"
     )]
     #[merge(strategy = merge::vec::append)]
+    #[serde_as(as = "OneOrMany<_>")]
     pub use_profile: Vec<String>,
 
     /// Only show what would be done without modifying anything. Does not affect read-only commands.
@@ -146,6 +147,11 @@ pub struct GlobalOptions {
     #[merge(strategy = merge::bool::overwrite_false)]
     pub dry_run: bool,
 
+    /// Check if index matches pack files and read pack headers if neccessary
+    #[clap(long, global = true, env = "RUSTIC_CHECK_INDEX")]
+    #[merge(strategy = merge::bool::overwrite_false)]
+    pub check_index: bool,
+
     /// Use this log level [default: info]
     #[clap(long, global = true, env = "RUSTIC_LOG_LEVEL")]
     pub log_level: Option<String>,
